	function Activities() {
		/* Object for the Activities Screen */
		this.item = null;
		this.total = 0;
		this.lindex = 0;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Activities.prototype.initialize = function() {
		browsr.screen = SCREEN_ACTIVITIES;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();
	}
	
	Activities.prototype.destroy = function() {
		flickr.purge_all();
		
		this.item = null;
		this.total = 0;
		this.lindex = 0;
		
		Helper.destroy(this);
	}
	
	Activities.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Activities.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
					Helper.keyUpListNav(this);
				else
					Helper.keyUpScroll(this);
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
					Helper.keyDownListNav(this);
				else
					Helper.keyDownScroll(this);
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(!(Helper.isListMode()))
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(!(Helper.isListMode()))
					this.keyRightTab();
				break;
		}
	}
	
	Activities.prototype.keyEnter = function() {
		if(this.total)
		{
			var tevent = this.getSelectedActivity();
			var titem = this.item;
			var lindex = this.lindex;
			
			var params = [];
			params["item"] = titem;
			params["event"] = tevent;
				
			this.destroy();
			
			var ttitle = '';
			if(titem.title._content)
				ttitle = titem.title._content;
			else
				ttitle = '(untitled)';
				
			browsr.addEvent('Activity on: ' + ttitle, activity.show, params, lindex, activityImage, 'icon');
			activity.show(params);
			params = null;
		}
	}
	
	Activities.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Activities.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Activities.prototype.refresh = function() {
		this.displayActivities();
	}
	
	Activities.prototype.showInBrowser = function() {
		if(this.item)
		{
			var url = 'http://www.flickr.com/activity/';
			openURL(url);
		}
		else
		{
			alert('Unable to open in browser!');
		}
	}
	
	Activities.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
			wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			toolbar.show(MENU_SHOW_IN_BROWSER.id);
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Activities.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.displayActivities();
	}
	
	Activities.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.displayActivities();
	}
	
	Activities.prototype.show = function(params) {
	
		if(params == null)
			params["item"] = null;
		
		if((params["item"] == undefined) || (params["item"] == null))
			params["activities"] = null;
			
		activities.item = params["item"];
		activities.initialize();
		
		if(activities.item != null)
		{
			if(activities.item.title && activities.item.title._content)
				Helper.setTitle('Recent activities on ' + activities.item.title._content);
			else
				Helper.setTitle('Recent activities on ' + '(untitled)');
				
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
				activities.lindex = params["sindex"];
				
			/* Split the events into pages as while on back that will have problems */
			
			if(activities.item.activity && activities.item.activity.event)
			{
				activities.total = activities.item.activity.event.length;
				activities.displayActivities();
			}
			else
			{
				activities.displayNoActivities();
			}
		}
	}
	
	Activities.prototype.displayActivities = function () {
		if(Helper.isListMode())
			this.displayActivitiesList();
		else
			this.displayActivitiesTabs();
	}
	
	Activities.prototype.displayActivitiesList = function () {
		if(this.selector)
			this.selector.removeAll();
			
		var tevents = this.item.activity.event;
		
		/* add to selector */
		for(var i=0; i < tevents.length; i++)
		{
			var text = '';
			var tevent = tevents[i];
			var image = bulletImage;
			
			if(tevent.type == 'comment')
				image = commentsImage;
			else if(tevent.type == 'note')
				image = notesImage;
			else if(tevent.type == 'tag')
				image = tagsImage;
			else if(tevent.type == 'fave')
				image = favsImage;
			
			text = text + tevent.username;
			
			this.selector.addElement(text, image, 'icon');
			
			if(image == bulletImage)
				Helper.hideIconGloss(i);
		}
		
		Helper.postDisplayList(this);
	}
	
	Activities.prototype.displayActivitiesTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tevent = this.item.activity.event[sindex];
		
		var title = tevent.username;
		var image = null;
		
		var subtitle = '';
		if(this.item.title && this.item.title._content)
			subtitle = activities.item.title._content;
		else
			subtitle = '(untitled)';
		
		if(tevent.type == 'comment')
		{
			subtitle = 'Commented on ' + subtitle;
			image = commentsImage;
		}
		else if(tevent.type == 'note')
		{
			subtitle = 'Added note on ' + subtitle;
			image = notesImage;
		}
		else if(tevent.type == 'tag')
		{
			subtitle = 'Added tag on' + subtitle;
			image = tagsImage;
		}
		else if(tevent.type == 'fave')
		{
			subtitle = 'Added ' + subtitle + 'as a note';
			image = favsImage;
		}
		
		Helper.displayTabPage(this, this.lindex, title, subtitle, image, 'icon');
		this.auto_disp_tid = setTimeout( function() { activities.autoFetch() } , Constants.AUTO_FETCH_TIMEOUT);
		
		Helper.postDisplayTabs(this);
	}
	
	Activities.prototype.displayNoActivities = function () {
		this.selector = null;
		var div = Helper.displayNoType('No Recent Activity found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Activities.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Activities.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Activities.prototype.autoFetch = function() {
		var tevent = this.getSelectedActivity();
		var text = '';
		
		if(!(Helper.isListMode()))
			this.tabs.autoFetch();
		
		var sindex = Helper.getSindex(this);
	
		if(tevent.type == 'comment')
			text = 'Commented: ' + tevent._content;
		else if(tevent.type == 'tag')
			text = 'Added Tag: ' + tevent._content;
		else if(tevent.type == 'fave')
			text = 'Added as Favorite!';
		else if(tevent.type == 'note')
			text = 'Added Note: ' + tevent._content;
				
		if(text.length > MAX_AF_TEXT_LENGTH)
		{
			text = text.substr(0, MAX_AF_TEXT_LENGTH);
			text = text + '...';
		}
			
		Helper.setAFText(sindex, text);
			
		this.resize();
		this.scroll.updateScrollbar();
	}
	
	Activities.prototype.getSelectedActivity = function() {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			sindex = this.lindex % MAX_LIST_SIZE;
		}
	
		if(this.total)
			return this.item.activity.event[sindex];
		else
			return null;
	}
	
	