	function Bookmarks() {
		/* Object for the Bookmarks Screen */
		this.page = [];
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Bookmarks.prototype.initialize = function() {
		browsr.screen = SCREEN_BOOKMARKS;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();
	}
	
	Bookmarks.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.by_photo = false;
		this.by_contact = false;
		this.by_set = false;
		
		Helper.destroy(this);
	}
	
	Bookmarks.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Bookmarks.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
					Helper.keyUpListNav(this);
				else
					Helper.keyUpScroll(this);
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
					Helper.keyDownListNav(this);
				else
					Helper.keyDownScroll(this);
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	Bookmarks.prototype.keyEnter = function() {
		if(this.total)
		{	
			var tid = this.getSelectedBookmark();
			var lindex = this.selectedListItem();
			
			if(this.by_photo)
			{
				var params = [];
				
				params["photo_id"] = tid.id;
				params["photo_title"] = tid.title;
				
				this.destroy();
				
				browsr.addEvent('Photo: ' + tid.title, photo.showByBookmark, params, lindex, null, 'photoframe');
				photo.showByBookmark(params);
				params = null;
			}
			else if(this.by_contact)
			{
				var params = [];
				
				params["user_id"] = tid.id;
				params["username"] = tid.name;
				
				this.destroy();
				
				browsr.addEvent('User: ' + tid.name, contact.showByBookmark, params, lindex, null, 'photoframe');
				contact.showByBookmark(params);
				params = null;
			}
			else if(this.by_set)
			{
				var params = [];
				
				params["set_id"] = tid.id;
				params["set_title"] = tid.title;
				
				this.destroy();
				
				browsr.addEvent('Set: ' + tid.name, set.showByBookmark, params, lindex, null, 'photoframe');
				set.showByBookmark(params);
				params = null;
			}
		}
	}
	
	Bookmarks.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	Bookmarks.prototype.keyRightList = function() {	
		Helper.keyRightList(this);
	}
	
	Bookmarks.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Bookmarks.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Bookmarks.prototype.refresh = function() {
		this.displayBookmarks();
	}
	
	Bookmarks.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
			wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			wid(MENU_SHOW_IN_BROWSER.id).setDimmed(true);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			toolbar.hide(MENU_SHOW_IN_BROWSER.id);
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Bookmarks.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.displayBookmarks();
	}
	
	Bookmarks.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.displayBookmarks();
	}
	
	Bookmarks.prototype.showByPhotos = function(params) {
		
		bookmarks.initialize();
		
		if(bmarks)
		{
			bookmarks.by_photo = true;
			
			Helper.setTitle('Bookmarks - Photos');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				bookmarks.lindex = params["sindex"];
				bookmarks.cur_page = parseInt(bookmarks.lindex / MAX_LIST_SIZE) + 1;
			}
	
			bookmarks.total = 0;
			var cur_page = bookmarks.cur_page;
				
			if(bmarks.photos)
			{
				var tbookmarks = bmarks.photos.slice(0, bmarks.photos.length);
				bookmarks.total = bmarks.photos.length;
				bookmarks.cur_page = 1;
				
				while(tbookmarks.length)
				{
					if(tbookmarks.length > MAX_LIST_SIZE)
					{
						bookmarks.page[bookmarks.cur_page] = tbookmarks.slice(0, MAX_LIST_SIZE);
						tbookmarks.splice(0, MAX_LIST_SIZE);
						bookmarks.cur_page++;
					}
					else
					{
						bookmarks.page[bookmarks.cur_page] = tbookmarks.slice(0, tbookmarks.length);
						tbookmarks.splice(0, tbookmarks.length);
						bookmarks.cur_page++;
					}
				}
					
				tbookmarks = null;
			}
				
			if(bookmarks.total)
			{
				bookmarks.pages = bookmarks.cur_page-1;
				bookmarks.cur_page = cur_page;
			}
			
			if(bookmarks.total)
			{
				bookmarks.displayBookmarks();
			}
			else
			{
				bookmarks.selector = null;
				var div = Helper.displayNoType('No photos found in bookmarks!');
				bookmarks.scroll.add(div);
				bookmarks.updateMenus();
			}
		}
		else
		{
			bookmarks.selector = null;
			var div = Helper.displayNoType('No photos found in bookmarks!');
			bookmarks.scroll.add(div);
			bookmarks.updateMenus();
		}
	}
	
	Bookmarks.prototype.showByContacts = function(params) {
		
		bookmarks.initialize();
		
		if(bmarks)
		{
			bookmarks.by_contact = true;
			
			Helper.setTitle('Bookmarks - Contacts');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				bookmarks.lindex = params["sindex"];
				bookmarks.cur_page = parseInt(bookmarks.lindex / MAX_LIST_SIZE) + 1;
			}
	
			bookmarks.total = 0;
			var cur_page = bookmarks.cur_page;
				
			if(bmarks.contacts)
			{
				var tbookmarks = bmarks.contacts.slice(0, bmarks.contacts.length);
				bookmarks.total = bmarks.contacts.length;
				bookmarks.cur_page = 1;
				
				while(tbookmarks.length)
				{
					if(tbookmarks.length > MAX_LIST_SIZE)
					{
						bookmarks.page[bookmarks.cur_page] = tbookmarks.slice(0, MAX_LIST_SIZE);
						tbookmarks.splice(0, MAX_LIST_SIZE);
						bookmarks.cur_page++;
					}
					else
					{
						bookmarks.page[bookmarks.cur_page] = tbookmarks.slice(0, tbookmarks.length);
						tbookmarks.splice(0, tbookmarks.length);
						bookmarks.cur_page++;
					}
				}
					
				tbookmarks = null;
			}
				
			if(bookmarks.total)
			{
				bookmarks.pages = bookmarks.cur_page-1;
				bookmarks.cur_page = cur_page;
			}
			
			if(bookmarks.total)
			{
				bookmarks.displayBookmarks();
			}
			else
			{
				bookmarks.selector = null;
				var div = Helper.displayNoType('No contacts found in bookmarks!');
				bookmarks.scroll.add(div);
				bookmarks.updateMenus();
			}
		}
		else
		{
			bookmarks.selector = null;
			var div = Helper.displayNoType('No contacts found in bookmarks!');
			bookmarks.scroll.add(div);
			bookmarks.updateMenus();
		}
	}
	
	Bookmarks.prototype.showBySets = function(params) {
		
		bookmarks.initialize();
		
		if(bmarks)
		{
			bookmarks.by_set = true;
			
			Helper.setTitle('Bookmarks - Sets');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				bookmarks.lindex = params["sindex"];
				bookmarks.cur_page = parseInt(bookmarks.lindex / MAX_LIST_SIZE) + 1;
			}
	
			bookmarks.total = 0;
			var cur_page = bookmarks.cur_page;
				
			if(bmarks.sets)
			{
				var tbookmarks = bmarks.sets.slice(0, bmarks.sets.length);
				bookmarks.total = bmarks.sets.length;
				bookmarks.cur_page = 1;
				
				while(tbookmarks.length)
				{
					if(tbookmarks.length > MAX_LIST_SIZE)
					{
						bookmarks.page[bookmarks.cur_page] = tbookmarks.slice(0, MAX_LIST_SIZE);
						tbookmarks.splice(0, MAX_LIST_SIZE);
						bookmarks.cur_page++;
					}
					else
					{
						bookmarks.page[bookmarks.cur_page] = tbookmarks.slice(0, tbookmarks.length);
						tbookmarks.splice(0, tbookmarks.length);
						bookmarks.cur_page++;
					}
				}
					
				tbookmarks = null;
			}
				
			if(bookmarks.total)
			{
				bookmarks.pages = bookmarks.cur_page-1;
				bookmarks.cur_page = cur_page;
			}
			
			if(bookmarks.total)
			{
				bookmarks.displayBookmarks();
			}
			else
			{
				bookmarks.selector = null;
				var div = Helper.displayNoType('No sets found in bookmarks!');
				bookmarks.scroll.add(div);
				bookmarks.updateMenus();
			}
		}
		else
		{
			bookmarks.selector = null;
			var div = Helper.displayNoType('No sets found in bookmarks!');
			bookmarks.scroll.add(div);
			bookmarks.updateMenus();
		}
	}
	
	Bookmarks.prototype.displayBookmarks = function () {
		if(Helper.isListMode())
			this.displayBookmarksList();
		else
			this.displayBookmarksTabs();
	}
	
	Bookmarks.prototype.displayBookmarksList = function () {
		if(this.selector)
			this.selector.removeAll();
		
		var tbookmarks = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < tbookmarks.length; i++)
		{
			var tbookmark = tbookmarks[i];
			var text = '';
			var image = bulletImage;
			
			if(this.by_photo)
			{
				text = tbookmark.title;
				image = photoImage;
			}
			else if(this.by_contact)
			{
				text = tbookmark.name;
				image = contactsImage;
			}
			else if(this.by_set)
			{
				text = tbookmark.title;
				image = setsImage;
			}
			
			this.selector.addElement(text, image, 'icon');
			Helper.hideIconGloss(i);
		}
		
		Helper.postDisplayList(this);
	}
	
	Bookmarks.prototype.displayBookmarksTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tbookmark = this.page[this.cur_page][sindex];
		
		var title = '';
		var subtitle = '';
		var image = '';
		
		if(this.by_photo)
		{
			title = tbookmark.title;
			subtitle = 'Bookmarks - Photos';
			image = photoImage;
		}
		else if(this.by_contact)
		{
			title = tbookmark.name;
			subtitle = 'Bookmarks - Contacts';
			image = contactsImage;
		}
		else if(this.by_set)
		{
			title = tbookmark.title;
			subtitle = 'Bookmarks - Sets';
			image = setsImage;
		}
		
		Helper.displayTabPage(this, this.lindex, title, subtitle, image, 'icon');
		this.auto_disp_tid = setTimeout( function() { bookmarks.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
		
		Helper.postDisplayTabs(this);
	}
	
	Bookmarks.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Bookmarks.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Bookmarks.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{
			var tbookmark = this.getSelectedBookmark();
			
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
			
			if(this.by_photo)
				flickr.photos_getInfo(user.token, tbookmark.id, null, this.hrPhotos, PRI_HIGH);
			else if(this.by_contact)
				flickr.people_getInfo(user.token, tbookmark.id, this.hrContacts, PRI_HIGH);
			else if(this.by_set)
				flickr.photosets_getInfo(user.token, tbookmark.id, this.hrSets, PRI_HIGH);
		}
	}
	
	Bookmarks.prototype.hrPhotos = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(bookmarks && rsp.photo)
				{	
					var tbookmark = bookmarks.getSelectedBookmark();
					var tphoto = rsp.photo;
					rsp = null;
					
					var sindex = Helper.getSindex(bookmarks);
						
					if(tbookmark.id == tphoto.id)
					{
						var photo_url = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
						
						Helper.setAFPhoto(sindex, photo_url, 'large');
						
						bookmarks.resize();
						bookmarks.scroll.updateScrollbar();
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}
	
	Bookmarks.prototype.hrContacts = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(bookmarks && rsp.person && bookmarks.selector)
				{	
					var tbookmark = bookmarks.getSelectedBookmark();
					var tperson = rsp.person;
					rsp = null;
					
					var sindex = Helper.getSindex(bookmarks);
						
					if(tbookmark.id == tperson.nsid)
					{
						var photo_url = flickr.build_buddy_icon_url(tperson.iconserver, tperson.iconfarm, tperson.nsid);
						
						Helper.setAFPhoto(sindex, photo_url, 'small');
						
						bookmarks.resize();
						bookmarks.scroll.updateScrollbar();
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}	
	
	Bookmarks.prototype.hrSets = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(bookmarks && rsp.photoset && bookmarks.selector)
				{	
					var tbookmark = bookmarks.getSelectedBookmark();
					var tset = rsp.photoset;
					rsp = null;
					
					if(!(Helper.isListMode()))
						Tabs.changeToAFTab(bookmarks.lindex);
					
					var sindex = Helper.getSindex(bookmarks);
						
					if(tbookmark.id == tset.id)
					{
						var photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_S);
						
						Helper.setAFPhoto(sindex, photo_url, 'large');
						
						bookmarks.resize();
						bookmarks.scroll.updateScrollbar();
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}	
	
	Bookmarks.prototype.getSelectedBookmark = function () {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
			return this.page[this.cur_page][sindex];
		else
			return null;
	}
	
		