	function Collections() {
		/* Object for the Collections Screen */
		this.page = [];
		this.user = null;
		this.collection = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Collections.prototype.initialize = function() {
		browsr.screen = SCREEN_COLLECTIONS;
		
		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();
	}
	
	Collections.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.user = null;
		this.collection = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		Helper.destroy(this);
	}
	
	Collections.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Collections.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
					Helper.keyUpListNav(this);
				else
					Helper.keyUpScroll(this);
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
					Helper.keyDownListNav(this);
				else
					Helper.keyDownScroll(this);
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	Collections.prototype.keyEnter = function() {
		if(this.total)
		{	
			var tcollection = this.getSelectedCollection();
			var tuser = this.user;
			var lindex = this.lindex;
			
			this.destroy();
			
			var params = [];
			
			if(tcollection.iconsmall)
			{
				/* collection */
				params["user"] = tuser;
				params["collection"] = tcollection;
				
				browsr.addEvent('Collection: ' + tcollection.title, collection.show, params, lindex, tcollection.iconsmall, 'photoframe');
				collection.show(params);
			}
			else
			{
				/* set */
				params["set"] = tcollection;
				
				var ttitle;
				if(tcollection.title._content)
					ttitle = tcollection.title._content;
				else
					ttitle = tcollection.title;
				
				browsr.addEvent('Set: ' + ttitle, set.show, params, lindex, null, 'photoframe');
				set.show(params);
			}
			params = null;
		}
	}
	
	Collections.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	Collections.prototype.keyRightList = function() {
		Helper.keyRightList(this);
	}
	
	Collections.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Collections.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Collections.prototype.refresh = function() {
		if(this.collection)
			this.displayItems();
		else
			this.displayCollections();
	}
	
	Collections.prototype.showInBrowser = function() {
		if(this.collection)
		{
			var url = 'http://www.flickr.com/photos/' + this.user.user_nsid + '/collections/' + this.collection.id + '/';
			openURL(url);
		}
		else if(this.user)
		{
			var url = 'http://www.flickr.com/photos/' + this.user.user_nsid + '/collections/';
			openURL(url);
		}
		else
		{
			alert('Unable to open in browser!');
		}
	}
	
	Collections.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
			wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
			
			if(this.collection && this.user)
				wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			else if(this.user)
				wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			else
				wid(MENU_SHOW_IN_BROWSER.id).setDimmed(true);
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			
			if(this.collection && this.user)
				toolbar.show(MENU_SHOW_IN_BROWSER.id);
			else if(this.user)
				toolbar.show(MENU_SHOW_IN_BROWSER.id);
			else
				toolbar.hide(MENU_SHOW_IN_BROWSER.id);
				
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Collections.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		
		if(this.collection)
			this.displayItems();
		else
			this.displayCollections();
	}
	
	Collections.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		
		if(this.collection)
			this.displayItems();
		else
			this.displayCollections();
	}

	Collections.prototype.showByUser = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
		}
		else if((params["user"] == undefined) || (params["user"] == null))
		{
			params["user"] = user;
		}
			
		collections.user = params["user"];
		collections.initialize();
		
		if(collections.user != null)
		{
			Helper.setTitle(collections.user.username + '\'s collections');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				collections.lindex = params["sindex"];
				collections.cur_page = parseInt(collections.lindex / MAX_LIST_SIZE) + 1;
			}
			
			flickr.collections_getTree(user.token, null, collections.user.user_nsid, collections.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Collections.prototype.showByCollection = function(params) {
	
		if(params == null)
		{
			params["collection"] = '';
			params["user"] = user;
		}
		else if((params["collection"] == undefined) || (params["collection"] == null))
		{
			params["collection"] = '';
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
		{
			params["user"] = user;
		}
			
		collections.collection = params["collection"];
		collections.user = params["user"];
		
		collections.initialize();
		
		if(collections.collection != null)
		{
			Helper.setTitle('Collection: ' + collections.collection.title + '\'s Items');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				collections.lindex = params["sindex"];
				collections.cur_page = parseInt(collections.lindex / MAX_LIST_SIZE) + 1;
			}
			
			flickr.collections_getTree(user.token, collections.collection.id, collections.user.user_nsid, collections.handleFlickrItemsResponse, PRI_HIGH);
		}
	}
	
	Collections.prototype.handleFlickrResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				var tcollections = rsp.collections;
				if(tcollections && tcollections.collection)
					collections.total = rsp.collections.collection.length;
					
				var cur_page = collections.cur_page;
				collection.cur_page = 1;
				
				rsp = null;
				
				while(tcollections.collection && tcollections.collection.length)
				{
					if(tcollections.collection.length > MAX_LIST_SIZE)
					{
						collections.page[collections.cur_page] = tcollections.collection.slice(0, MAX_LIST_SIZE);
						tcollections.collection.splice(0, MAX_LIST_SIZE);
						collections.cur_page++;
					}
					else
					{
						collections.page[collections.cur_page] = tcollections.collection.slice(0, tcollections.collection.length);
						tcollections.collection.splice(0, tcollections.collection.length);
						collections.cur_page++;
					}
				}
				
				tcollections = null;
				
				if(collections.total)
				{
					collections.pages = collections.cur_page-1;
					collections.cur_page = cur_page;
				}
				
				if(collections.total)
				{
					collections.displayCollections();
				}
				else
				{
					collections.displayNoCollection();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	Collections.prototype.handleFlickrItemsResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				var tcollections = rsp.collections.collection[0];
				collections.total = 0;
				
				if(tcollections.collection)
					collections.total += tcollections.collection.length;
				if(tcollections.set)
					collections.total += tcollections.set.length;
					
				var cur_page = collections.cur_page;
				collections.cur_page = 1;
				
				rsp = null;
				
				while(tcollections.collection && tcollections.collection.length)
				{
					if(tcollections.collection.length > MAX_LIST_SIZE)
					{
						collections.page[collections.cur_page] = tcollections.collection.slice(0, MAX_LIST_SIZE);
						tcollections.collection.splice(0, MAX_LIST_SIZE);
						collections.cur_page++;
					}
					else
					{
						collections.page[collections.cur_page] = tcollections.collection.slice(0, tcollections.collection.length);
						tcollections.collection.splice(0, tcollections.collection.length);
						collections.cur_page++;
					}
				}
				
				while(tcollections.set && tcollections.set.length)
				{
					if(tcollections.set.length > MAX_LIST_SIZE)
					{
						collections.page[collections.cur_page] = tcollections.set.slice(0, MAX_LIST_SIZE);
						tcollections.set.splice(0, MAX_LIST_SIZE);
						collections.cur_page++;
					}
					else
					{
						collections.page[collections.cur_page] = tcollections.set.slice(0, tcollections.set.length);
						tcollections.set.splice(0, tcollections.set.length);
						collections.cur_page++;
					}
				}
				
				tcollections = null;
				
				if(collections.total)
				{
					collections.pages = collections.cur_page-1;
					collections.cur_page = cur_page;
				}
				
				if(collections.total)
				{
					collections.displayItems();
				}
				else
				{
					collections.displayNoItem();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	Collections.prototype.displayCollections = function () {
		if(Helper.isListMode())
			this.displayCollectionsList();
		else
			this.displayCollectionsTabs();
	}
	
	Collections.prototype.displayCollectionsList = function () {
		if(this.selector)
			this.selector.removeAll();
		
		var tcollections = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < tcollections.length; i++)
		{
			var tcollection = tcollections[i];
			var photo_url = tcollection.iconsmall;
			
			this.selector.addElement(tcollection.title, photo_url, 'photoframe');
		}
		
		Helper.postDisplayList(this);
	}
	
	Collections.prototype.displayCollectionsTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tcollection = this.page[this.cur_page][sindex];
		var photo_url = tcollection.iconlarge;
		
		Helper.displayTabPage(this, this.lindex, tcollection.title, (this.user.username + '\'s Collections'), photo_url, 'photoframe');
		this.auto_disp_tid = setTimeout( function() { collections.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
			
		Helper.postDisplayTabs(this);
	}
	
	Collections.prototype.displayNoCollection = function () {
		this.selector = null;
		this.tab_container = null;
		var div = Helper.displayNoType('No collections found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Collections.prototype.displayItems = function () {
		if(Helper.isListMode())
			this.displayItemsList();
		else
			this.displayItemsTabs();
	}
	
	Collections.prototype.displayItemsList = function () {
		if(this.selector)
			this.selector.removeAll();
		
		var tcollections = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < tcollections.length; i++)
		{
			var tchild = tcollections[i];
			var photo_url = tchild.iconsmall;
			
			if(photo_url)
			{
				this.selector.addElement(tchild.title, photo_url, 'photoframe');
			}
			else
			{
				this.selector.addElement(tchild.title, itemsImage, 'icon');
				
				/* Generate request for the icon */
				flickr.photosets_getInfo(user.token, tchild.id, this.handleSetsIconsResponse, PRI_LOW);
			}
		}
		
		Helper.postDisplayList(this);
	}
	
	Collections.prototype.displayItemsTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tcollection = this.page[this.cur_page][sindex];
		var photo_url = tcollection.iconlarge;
		
		if(!photo_url)
		{
			// TODO: Need to get set's photo here!!
		}
		if(photo_url)
		{
			Helper.displayTabPage(this, this.lindex, tcollection.title, ('Collection: ' + this.collection.title + '\'s Items'), photo_url, 'photoframe');
		}
		else
		{
			Helper.displayTabPage(this, this.lindex, tcollection.title, ('Collection: ' + this.collection.title + '\'s Items'), itemsImage, 'icon');
		}
		this.auto_disp_tid = setTimeout( function() { collections.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
			
		Helper.postDisplayTabs(this);
	}
	
	Collections.prototype.displayNoItem = function () {
		this.selector = null;

		var div = Helper.displayNoType('No items found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Collections.prototype.handleSetsIconsResponse = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(collections && collections.selector)
				{
					if(rsp.photoset)
					{
						var tset = rsp.photoset;
						var photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_S);
						rsp = null;
						
						var set_index = -1;
						var current_page = collections.page[collections.cur_page];
						
						for(var i=0; i < current_page.length; i++)
						{
							if(current_page[i].id == tset.id)
							{
								set_index = i;
								collections.selector.replaceElement(set_index, tset.title._content, photo_url);
							}
						}
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}
	
	Collections.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Collections.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Collections.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{	
			var tcollection = this.getSelectedCollection();
			
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
				
			var sindex = Helper.getSindex(this);
			
			if(tcollection.iconsmall)
			{
				/* find if children are collection or sets */
				
				var tchild = null;
				
				if(tcollection.collection)
				{
					/* collection */
					tchild = tcollection.collection;
					
					Helper.destroyDescendants($('autof_elt_' + sindex));
					var photo_url = [];
					for(var i=0; (i < tchild.length) && (i < Constants.AUTO_FETCH_PHOTOCOUNT); i++)
					{
						photo_url[i] = tchild[i].iconsmall;
					}
					
					Helper.setAFPhotoList(sindex, photo_url, 'large');
					collections.resize();
					collections.scroll.updateScrollbar();
				}
				else
				{
					/* set */
					tchild = tcollection.set;
					
					Helper.destroyDescendants($('autof_elt_' + sindex));
					for(var i=0; (i < tchild.length) && (i < Constants.AUTO_FETCH_PHOTOCOUNT); i++)
					{
						/* Send requests */
						flickr.photosets_getInfo(user.token, tchild[i].id, this.hrSets, PRI_HIGH);
					}
				}
			}
			else
			{
				/* set */
				flickr.photosets_getPhotos(user.token, tcollection.id, null, null, null, null, Constants.AUTO_FETCH_PHOTOCOUNT, this.hrPhotos, PRI_HIGH);
			}
		}
	}
	
	Collections.prototype.hrSets = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(collections)
				{
					var sindex = Helper.getSindex(collections);
						
					var photo_url = [];
					if(rsp.photoset)
					{
						var tset = rsp.photoset;
						var photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_S);
						rsp = null;
						
						var img = Helper.getAFLargePhoto(photo_url);
						$('autof_elt_' + sindex).appendChild(img);
						
						Helper.showAutoFetch(sindex);
						collections.resize();
						collections.scroll.updateScrollbar();
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}
	
	Collections.prototype.hrPhotos = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				var tphotostream = rsp.photoset.photo;
				var rsp_id = rsp.photoset.id;
				rsp = null;
				
				if(collections)
				{
					var sindex = Helper.getSindex(collections);
						
					/* check if the owner of the rsp and the owner of the selected item match */			
					var sel_id = (collections.getSelectedCollection()).id;
					
					if(rsp_id == sel_id)
					{
						if(tphotostream.length)
						{
							Helper.destroyDescendants($('autof_elt_' + sindex));
							var photo_url = [];
							for(var i=0; i < tphotostream.length; i++)
							{
								var tphoto = tphotostream[i];
								photo_url[i] = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
							}
							
							Helper.setAFPhotoList(sindex, photo_url, 'large');
							collections.resize();
							collections.scroll.updateScrollbar();
						}
						else
						{
							Helper.setAFNoResult(sindex, 'No photos available!');
							collections.resize();
							collections.scroll.updateScrollbar();
						}
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}
	
	Collections.prototype.getSelectedCollection = function() {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
			return this.page[this.cur_page][sindex];
		else
			return null;
	}
	
	