	function Notes() {
		/* Object for the Notes Screen */
		this.page = [];
		this.photo = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Notes.prototype.initialize = function() {
		browsr.screen = SCREEN_NOTES;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();

	}
	
	Notes.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.photo = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		Helper.destroy(this);
	}
	
	Notes.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Notes.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
					Helper.keyUpListNav(this);
				else
					Helper.keyUpScroll(this);
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
					Helper.keyDownListNav(this);
				else
					Helper.keyDownScroll(this);
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	Notes.prototype.keyEnter = function() {
		if(this.total)
		{	
			var tnote = this.getSelectedNote();
			var lindex = this.lindex;
			
			var params = [];
			
			params["photo"] = this.photo;
			params["note"] = tnote;
			
			var ttitle = '';
			if(this.photo.title)
				ttitle = this.photo.title;
			else
				ttitle = '(untitled)';
			
			var tphoto = this.photo;
			
			var photo_url = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
			
			this.destroy();
			
			browsr.addEvent( ttitle+ '\'s Notes', sphoto.showByNote, params, lindex, photo_url, 'photoframe');
			sphoto.showByNote(params);
			params = null;
		}
	}
	
	Notes.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	Notes.prototype.keyRightList = function() {
		Helper.keyRightList(this);
	}
	
	Notes.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Notes.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Notes.prototype.refresh = function() {
		this.displayNotes();
	}
	
	Notes.prototype.showInBrowser = function() {
		if(this.photo)
		{
			var url = 'http://www.flickr.com/photos/' + this.photo.owner + '/' + this.photo.id + '/'
			openURL(url);
		}
		else
		{
			alert('Unable to open in browser!');
		}
	}
	
	Notes.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
			wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			toolbar.show(MENU_SHOW_IN_BROWSER.id);
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Notes.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.displayNotes();
	}
	
	Notes.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.displayNotes();
	}
	
	Notes.prototype.showByPhoto = function(params) {
	
		if(params == null)
		{
			params["photo"] = null;
		}
		else if((params["photo"] == undefined) || (params["photo"] == null))
		{
			params["photo"] = null;
		}
			
		notes.photo = params["photo"];
		notes.initialize();
		
		if(notes.photo != null)
		{
		
			if(notes.photo.title != '')
				Helper.setTitle('Notes for: ' + notes.photo.title);
			else
				Helper.setTitle('Notes for: ' + '(untitled)');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				notes.lindex = params["sindex"];
				notes.cur_page = parseInt(notes.lindex / MAX_LIST_SIZE) + 1;
			}
			
			flickr.photos_getInfo(user.token, notes.photo.id, notes.photo.secret, notes.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Notes.prototype.handleFlickrResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				notes.total = 0;
				var cur_page = notes.cur_page;
				
				if(rsp.photo && rsp.photo.notes && rsp.photo.notes.note)
				{
					var tnotes = rsp.photo.notes;
					notes.total = rsp.photo.notes.note.length;
					rsp = null;
					notes.cur_page = 1;
					
					while(tnotes.note.length)
					{
						if(tnotes.note.length > MAX_LIST_SIZE)
						{
							notes.page[notes.cur_page] = tnotes.note.slice(0, MAX_LIST_SIZE);
							tnotes.note.splice(0, MAX_LIST_SIZE);
							notes.cur_page++;
						}
						else
						{
							notes.page[notes.cur_page] = tnotes.note.slice(0, tnotes.note.length);
							tnotes.note.splice(0, tnotes.note.length);
							notes.cur_page++;
						}
					}
					
					tnotes = null;
				}
				
				if(notes.total)
				{
					notes.pages = notes.cur_page-1;
					notes.cur_page = cur_page;
				}
				
				if(notes.total)
				{
					notes.displayNotes();
				}
				else
				{
					notes.displayNoNote();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	Notes.prototype.displayNotes = function () {
		if(Helper.isListMode())
			this.displayNotesList();
		else
			this.displayNotesTabs();
	}
	
	Notes.prototype.displayNotesList = function () {
		if(this.selector)
			this.selector.removeAll();
		
		var tnotes = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < tnotes.length; i++)
		{
			this.selector.addElement(tnotes[i].authorname, notesImage, 'icon');
			Helper.hideIconGloss(i);
		}
		
		Helper.postDisplayList(this);
	}
	
	Notes.prototype.displayNotesTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tnote = this.page[this.cur_page][sindex];

		var subtitle = '';
		if(this.photo.title != '')
			subtitle = 'Sizes for: ' + this.photo.title;
		else
			subtitle = 'Sizes for: ' + '(untitled)';
		
		Helper.displayTabPage(this, this.lindex, tnote.authorname, subtitle, notesImage, 'icon');
		this.auto_disp_tid = setTimeout( function() { notes.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
		
		Helper.postDisplayTabs(this);
	}
	
	Notes.prototype.displayNoNote = function () {
		this.selector = null;
		var div = Helper.displayNoType('No notes found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Notes.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Notes.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Notes.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{	
			var tnote = this.getSelectedNote();
				
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
			
			var sindex = Helper.getSindex(this);
			
			var text = tnote._content;
			
			if(text.length > MAX_AF_TEXT_LENGTH)
			{
				text = text.substr(0, MAX_AF_TEXT_LENGTH);
				text = text + '...';
			}
			
			Helper.setAFText(sindex, text);
			this.resize();
			this.scroll.updateScrollbar();
		}
	}
		
	Notes.prototype.getSelectedNote = function() {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
			return this.page[this.cur_page][sindex];
		else
			return null;
	}
		
	