	function Photostream() {
		/* Object for the Photostream Screen */
		this.page = [];
		this.user = null;
		this.set = null;
		this.user_id = '';
		this.date = '';
		this.search_text = '';
		this.search_tags = '';
		this.place = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.by_user = false;
		this.by_set = false;
		this.by_tag = false;
		this.by_favorites = false;
		this.by_contact_recent = false;
		this.by_public_recent = false;
		this.by_explore_today = false;
		this.by_explore_date = false;
		this.by_search_text = false;
		this.by_search_tags = false;
		this.by_place = false;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Photostream.prototype.initialize = function() {
		browsr.screen = SCREEN_PHOTOSTREAM;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();

	}
	
	Photostream.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.user = null;
		this.set = null;
		this.user_id = '';
		this.date = '';
		this.search_text = '';
		this.search_tags = '';
		this.place = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.by_user = false;
		this.by_set = false;
		this.by_tag = false;
		this.by_favorites = false;
		this.by_contact_recent = false;
		this.by_public_recent = false;
		this.by_explore_today = false;
		this.by_explore_date = false;
		this.by_search_text = false;
		this.by_search_tags = false;
		this.by_place = false;
		
		Helper.destroy(this);
	}
	
	Photostream.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Photostream.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
				{
					Helper.keyUpListNav(this);
					this.updateBookmarkMenus();
				}
				else
				{
					Helper.keyUpScroll(this);
				}
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
				{
					Helper.keyDownListNav(this);
					this.updateBookmarkMenus();
				}
				else
				{
					Helper.keyDownScroll(this);
				}
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	Photostream.prototype.keyEnter = function() {
		if(this.total)
		{
			var tphoto = this.getSelectedPhoto();
			var lindex = this.lindex;
			
			var params = [];
			params["photo"] = tphoto;
			
			if(this.by_user)
				params["user_id"] = this.user.user_nsid;
			else if(this.by_favorites || this.by_contact_recent || this.by_public_recent || this.by_explore_today || this.by_explore_date || this.by_search_text || this.by_search_tags || this.by_place)
				params["user_id"] = tphoto.owner;
			else
				params["user_id"] = this.user_id;
				
			var photo_url = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
				
			this.destroy();
			
			var ttitle = 'Photo: ';
			if(tphoto.title != '')
				ttitle += tphoto.title;
			else
				ttitle += '(untitled)';
			
			browsr.addEvent(ttitle, photo.show, params, lindex, photo_url, 'photoframe');
			photo.show(params);
			params = null;
		}
	}
	
	Photostream.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	Photostream.prototype.keyRightList = function() {
		Helper.keyRightList(this);	
	}
	
	Photostream.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Photostream.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Photostream.prototype.refresh = function() {
		if(this.page[this.cur_page])
		{
			flickr.purge_all();
			this.displayPhotostream();
		}
		else
		{
			flickr.purge_all();
			
			if(this.by_user == true)
			{
				flickr.purge_all();
				var params = [];
				params["user"] = this.user;
				params["page"] = this.cur_page;
				
				this.showByUser(params);
			}
			else if(this.by_set == true)
			{
				flickr.purge_all();
				var params = [];
				params["set"] = this.set;
				params["page"] = this.cur_page;
				
				this.showBySet(params);
			}
			else if(this.by_tag == true)
			{
				flickr.purge_all();
				var params = [];
				params["user_id"] = this.user_id;
				params["tag"] = this.tag;
				params["page"] = this.cur_page;
				
				this.showByTag(params);
			}
			else if(this.by_favorites == true)
			{
				flickr.purge_all();
				var params = [];
				params["user"] = this.user;
				params["page"] = this.cur_page;
				
				this.showByFavorites(params);
			}
			else if(this.by_contact_recent == true)
			{
				flickr.purge_all();
				var params = [];
				params["user"] = this.user;
				params["page"] = this.cur_page;
				
				this.showByContactRecent(params);
			}
			else if(this.by_public_recent == true)
			{
				flickr.purge_all();
				var params = [];
				params["user"] = this.user;
				params["page"] = this.cur_page;
				
				this.showByPublicRecent(params);
			}
			else if(this.by_explore_today == true)
			{
				flickr.purge_all();
				var params = [];
				params["page"] = this.cur_page;
				
				this.showByExploreToday(params);
			}
			else if(this.by_explore_date == true)
			{
				flickr.purge_all();
				var params = [];
				params["date"] = this.date;
				params["page"] = this.cur_page;
				
				this.showByExploreDate(params);
			}
			else if(this.by_search_text == true)
			{
				flickr.purge_all();
				var params = [];
				params["text"] = this.search_text;
				params["page"] = this.cur_page;
				
				this.showBySearchText(params);
			}
			else if(this.by_search_tags == true)
			{
				flickr.purge_all();
				var params = [];
				params["tags"] = this.search_tags;
				params["page"] = this.cur_page;
				this.lindex = 0;
				
				this.showBySearchTags(params);
			}
			else if(this.by_place == true)
			{
				flickr.purge_all();
				var params = [];
				params["place"] = this.place;
				params["page"] = this.cur_page;
				
				this.showByPlace(params);
			}
		}
	}
	
	Photostream.prototype.showInBrowser = function() {
		if(this.total)
		{
			var tphoto = this.getSelectedPhoto();
				
			var towner = null;
			if(this.by_user)
				towner = this.user.user_nsid;
			else if(this.by_favorites || this.by_contact_recent || this.by_public_recent || this.by_explore_today || this.by_explore_date || this.by_search_text || this.by_search_tags || this.by_place)
				towner = tphoto.owner;
			else
				towner = this.user_id;
			
			var url = 'http://www.flickr.com/photos/' + towner + '/' + tphoto.id;
			openURL(url);
		}
		else
		{
			alert('Unable to open in browser!');
		}
	}
	
	Photostream.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
			
			this.updateBookmarkMenus();
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			toolbar.show(MENU_SHOW_IN_BROWSER.id);
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Photostream.prototype.updateBookmarkMenus = function() {
		var tphoto = this.getSelectedPhoto();
		
		if(tphoto && bmarks)
		{
			if(bmarks.findPhotoInBmarks(tphoto.id))
			{
				wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
				wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(false);
			}
			else
			{	
				wid(MENU_ADD_TO_BMARKS.id).setDimmed(false);
				wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			}
		}
	}
		
	Photostream.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.refresh();
	}
	
	Photostream.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.refresh();
	}
	
	Photostream.prototype.showByUser = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		photostream.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.user != null)
		{
			photostream.by_user = true;
			Helper.setTitle(photostream.user.username + '\'s photostream');
			
			var fparams = [];
			
			fparams["method"] = "flickr.photos.search";
			fparams["user_id"] = photostream.user.user_nsid;
			fparams["auth_token"] = user.token;
			fparams["per_page"] = MAX_LIST_SIZE;
			fparams["extras"] = "views, owner_name, date_upload";
			
			if(params["page"])
				fparams["page"] = '' + params["page"];
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				fparams["page"] =  photostream.cur_page;
			}
				
			/* send request to flickr */
			flickr.photos_search(fparams, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showBySet = function(params) {
	
		if(params == null)
		{
			params["set"] = null;
			params["page"] = null;
		}
		
		if((params["set"] == undefined) || (params["set"] == null))
			params["set"] = null;
			
		photostream.set = params["set"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.set != null)
		{
			photostream.by_set = true;
			if(photostream.set.title._content)
			{
				Helper.setTitle('Set: ' + photostream.set.title._content);
			}
			else
			{
				Helper.setTitle('Set: ' + photostream.set.title);
			}
			
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				page = photostream.cur_page;
			}
			
			flickr.photosets_getPhotos(user.token, photostream.set.id, 'views, owner_name, date_upload', null, null, page, MAX_LIST_SIZE, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showByTag = function(params) {
	
		if(params == null)
		{
			params["user_id"] = null;
			params["tag"] = null;
			params["page"] = null;
		}
		
		if((params["tag"] == undefined) || (params["tag"] == null))
			params["tag"] = null;
			
		photostream.tag = params["tag"];
		
		if((params["user_id"] == undefined) | (params["user_id"] == null))
			params["user_id"] = user.user_nsid;
			
		photostream.user_id = params["user_id"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.tag != null)
		{
			photostream.by_tag = true;
			Helper.setTitle('Tag: ' + photostream.tag._content);
			
			var fparams = [];
			
			fparams["method"] = "flickr.photos.search";
			
			if(params["user_id"])
				fparams["user_id"] = params["user_id"];
				
			fparams["tags"] = photostream.tag._content;
			fparams["auth_token"] = user.token;
			fparams["per_page"] = MAX_LIST_SIZE;
			fparams["extras"] = "views, owner_name, date_upload";
			
			if(params["page"])
				fparams["page"] = '' + params["page"];
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				fparams["page"] = photostream.cur_page;
			}
			
			/* send request to flickr */
			flickr.photos_search(fparams, photostream.handleFlickrResponse);
		}
	}
	
	Photostream.prototype.showByFavorites = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		photostream.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.user != null)
		{
			photostream.by_favorites = true;
			Helper.setTitle(photostream.user.username + '\'s favorites');
			
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				page = photostream.cur_page;
			}
			
			flickr.favorites_getList(user.token, photostream.user.user_nsid, null, null, 'views, owner_name, date_upload', page, MAX_LIST_SIZE, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showByContactRecent = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		photostream.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.user != null)
		{
			photostream.by_contact_recent = true;
			Helper.setTitle(photostream.user.username + '\'s contacts\' recent');
			
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				page = photostream.cur_page;
			}
			
			/* 50 is the max value */
			flickr.photos_getContactsPhotos(user.token, 50, null, null, null, 'views, owner_name, date_upload', photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showByPublicRecent = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		photostream.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		/* this check is not needed */
		if(photostream.user != null)
		{
			photostream.by_public_recent = true;
			Helper.setTitle('Public photos');
			
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				page = photostream.cur_page;
			}
			
			flickr.photos_getRecent(user.token, 'views, owner_name, date_upload', page, MAX_LIST_SIZE, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showByExploreToday = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		photostream.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		/* this check is not needed */
		if(photostream.user != null)
		{
			photostream.by_explore_today = true;
			Helper.setTitle('Explore Today');
			
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				page = photostream.cur_page;
			}
			
			flickr.interestingness_getList(user.token, null, 'views, owner_name, date_upload', page, MAX_LIST_SIZE, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showByExploreDate = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["date"] = null;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		photostream.user = params["user"];
		
		if((params["date"] == undefined) || (params["date"] == null))
			params["date"] = null;
			
		photostream.date = params["date"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.date != null)
		{
			photostream.by_explore_date = true;
			Helper.setTitle('Explored On ' + photostream.date);
			
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				page = photostream.cur_page;
			}
			
			flickr.interestingness_getList(user.token, photostream.date, 'views, owner_name, date_upload', page, MAX_LIST_SIZE, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showBySearchText = function(params) {
	
		if(params == null)
		{
			params["text"] = null;
			params["page"] = null;
		}
		
		if((params["text"] == undefined) || (params["text"] == null))
			params["text"] = null;
			
		photostream.search_text = params["text"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.search_text != null)
		{
			photostream.by_search_text = true;
			Helper.setTitle('Search text: ' + photostream.search_text);
			
			var fparams = [];
			
			fparams["method"] = "flickr.photos.search";
			fparams["text"] = photostream.search_text;
			fparams["auth_token"] = user.token;
			fparams["per_page"] = MAX_LIST_SIZE;
			fparams["extras"] = "views, owner_name, date_upload";
			
			if(params["page"])
				fparams["page"] = '' + params["page"];
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				fparams["page"] =  photostream.cur_page;
			}
				
			/* send request to flickr */
			flickr.photos_search(fparams, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showBySearchTags = function(params) {
	
		if(params == null)
		{
			params["tags"] = null;
			params["page"] = null;
		}
		
		if((params["tags"] == undefined) || (params["tags"] == null))
			params["tags"] = null;
			
		photostream.search_tags = params["tags"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.search_tags != null)
		{
			photostream.by_search_tags = true;
			Helper.setTitle('Search tags: ' + photostream.search_tags);
			
			var fparams = [];
			
			fparams["method"] = "flickr.photos.search";
			fparams["tags"] = photostream.search_tags;
			fparams["auth_token"] = user.token;
			fparams["per_page"] = MAX_LIST_SIZE;
			fparams["extras"] = "views, owner_name, date_upload";
			
			if(params["page"])
				fparams["page"] = '' + params["page"];
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				fparams["page"] =  photostream.cur_page;
			}
				
			/* send request to flickr */
			flickr.photos_search(fparams, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.showByPlace = function(params) {
	
		if(params == null)
		{
			params["place"] = null;
			params["page"] = null;
		}
			
		if((params["place"] == undefined) || (params["place"] == null))
			params["place"] = null;
			
		photostream.place = params["place"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			photostream.initialize();
		
		if(photostream.place != null)
		{
			photostream.by_place = true;
			
			if(photostream.place._content)
				Helper.setTitle('Place: ' + photostream.place._content);
			else
				Helper.setTitle('Place: ' + photostream.place.name);
			
			var fparams = [];
			
			fparams["method"] = "flickr.photos.search";
			fparams["place_id"] = photostream.place.place_id;
			fparams["auth_token"] = user.token;
			fparams["per_page"] = MAX_LIST_SIZE;
			fparams["extras"] = "views, owner_name, date_upload";
			
			if(params["page"])
				fparams["page"] = '' + params["page"];
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				photostream.lindex = params["sindex"];
				photostream.cur_page = parseInt(photostream.lindex / MAX_LIST_SIZE) + 1;
				fparams["page"] =  photostream.cur_page;
			}
				
			/* send request to flickr */
			flickr.photos_search(fparams, photostream.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Photostream.prototype.handleFlickrResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(photostream.by_user == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_set == true)
				{
					var cur_page = parseInt(rsp.photoset.page);
					photostream.page[cur_page] = rsp.photoset;
					photostream.total = parseInt(rsp.photoset.total);
					photostream.pages = parseInt(rsp.photoset.pages);
					photostream.user_id = rsp.photoset.owner;
				}
				else if(photostream.by_tag == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_favorites == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_contact_recent == true)
				{
					photostream.total = 0;
					var cur_page = photostream.cur_page;
					
					if(rsp.photos)
					{
						var tphotostream = rsp.photos;
						photostream.total = rsp.photos.photo.length;
						rsp = null;
						photostream.cur_page = 1;
						
						while(tphotostream.photo.length)
						{
							if(tphotostream.photo.length > MAX_LIST_SIZE)
							{
								photostream.page[photostream.cur_page] = tphotostream.photo.slice(0, MAX_LIST_SIZE);
								tphotostream.photo.splice(0, MAX_LIST_SIZE);
								photostream.cur_page++;
							}
							else
							{
								photostream.page[photostream.cur_page] = tphotostream.photo.slice(0, tphotostream.photo.length);
								tphotostream.photo.splice(0, tphotostream.photo.length);
								photostream.cur_page++;
							}
						}
						
						tsets = null;
					}
						
					if(photostream.total)
					{
						photostream.pages = photostream.cur_page-1;
						photostream.cur_page = cur_page;
					}
				}
				else if(photostream.by_public_recent == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_explore_today == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_explore_date == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_search_text == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_search_tags == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				else if(photostream.by_place == true)
				{
					var cur_page = parseInt(rsp.photos.page);
					photostream.page[cur_page] = rsp.photos;
					photostream.total = parseInt(rsp.photos.total);
					photostream.pages = parseInt(rsp.photos.pages);
				}
				rsp = null;
				
				if((photostream.cur_page == cur_page) && photostream.total)
				{
					photostream.displayPhotostream();
				}
				else if(photostream.total == 0)
				{
					photostream.displayNoPhoto();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	Photostream.prototype.displayPhotostream = function () {
		if(Helper.isListMode())
			this.displayPhotostreamList();
		else
			this.displayPhotostreamTabs();
	}
	
	Photostream.prototype.displayPhotostreamList = function () {
		if(this.selector)
			this.selector.removeAll();
			
		var tphotostream = null;
		if(this.by_contact_recent)
			tphotostream = this.page[this.cur_page];
		else
			tphotostream = this.page[this.cur_page].photo;
		
		/* add to selector */
		for(var i=0; i < tphotostream.length; i++)
		{
			var tphoto = tphotostream[i];
			var photo_url = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
			
			if(tphoto.title != '')
			{
				this.selector.addElement(tphoto.title, photo_url, 'photoframe');
			}
			else
			{
				this.selector.addElement('(untitled)', photo_url, 'photoframe');
			}
		}
		
		Helper.postDisplayList(this);
	}
	
	Photostream.prototype.displayPhotostreamTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tphoto = null;
		if(this.by_contact_recent)
			tphoto = this.page[this.cur_page][sindex];
		else
			tphoto = this.page[this.cur_page].photo[sindex];
			
		var photo_url = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_M);
		
		var title = '';
		if(tphoto.title)
			title = tphoto.title;
		else
			title = '(untitled)';
			
		var subtitle = '';
		if(this.by_user)
			subtitle = this.user.username + '\'s Photos';
		else if(this.by_set)
		{
			if(this.set.title._content)
				subtitle = this.set.title._content + '\'s Photos';
			else
				subtitle = this.set.title;
		}
		else if(this.by_tag)
			subtitle = this.tag._content + '\'s Photos';
		else if(this.by_favorites)
			subtitle = this.user.username + '\'s Favorites';
		else if(this.by_contact_recent)
			subtitle = 'Your Contacts\' Recent Uploads';
		else if(this.by_public_recent)
			subtitle = 'Recent Public Photos';
		else if(this.by_explore_today)
			subtitle = 'Explore Today';
		else if(this.by_explore_date)
			subtitle = 'Explore On' + this.date;
		else if(this.by_search_text)
			subtitle = 'Search by text: ' + this.search_text;
		else if(this.by_search_tags)
			subtitle = 'Search by tags: ' + this.search_tags;
		else if(this.by_place)
		{
			if(this.place._content)
				subtitle = 'Place: ' + this.place._content;
			else
				subtitle = 'Place: ' + this.place.name;
		}
		
		Helper.displayTabPage(this, this.lindex, title, subtitle, photo_url, 'photoframe');
		
		this.auto_disp_tid = setTimeout( function() { photostream.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
		
		Helper.postDisplayTabs(this);
	}
	
	Photostream.prototype.displayNoPhoto = function () {
		this.selector = null;
		this.tab_container = null;
		var div = Helper.displayNoType('No photos found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Photostream.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Photostream.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Photostream.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{
			var tphoto = this.getSelectedPhoto();
			
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
				
			var sindex = Helper.getSindex(photostream);
			
			var dateupload = new Date();
			dateupload.setTime(tphoto.dateupload * 1000);
			
			var text = [];
			text[text.length] = tphoto.views + ' views since ';
			text[text.length] = dateupload.toLocaleDateString() + '.';
			
			var photo_url = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
			
			Helper.setAFPhotoTextList(sindex, photo_url, text, 'large', 'left');
			
			this.resize();
			this.scroll.updateScrollbar();
		}
	}
	
	Photostream.prototype.addToBookmarks = function() {
		if(this.cur_page && this.page[this.cur_page])
		{
			var tphoto = this.getSelectedPhoto();
			
			if(bmarks && tphoto)
			{
				var ttitle = '';
				
				if(tphoto.title != '')
					ttitle = tphoto.title;
				else
					ttitle = '(untitled)';
				
				bmarks.addPhotoToBmarks( {id:tphoto.id, title:ttitle} );
			}
		}
	}
	
	Photostream.prototype.removeFromBookmarks = function() {
		if(this.cur_page && this.page[this.cur_page])
		{
			var tphoto = this.getSelectedPhoto();
			
			if(bmarks && tphoto)
			{
				bmarks.removePhotoFromBmarks(tphoto.id);
			}
		}
	}
	
	Photostream.prototype.getSelectedPhoto = function() {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
		{
			if(this.by_contact_recent)
				return this.page[this.cur_page][sindex];
			else
				return this.page[this.cur_page].photo[sindex];
		}
		else
			return null;
	}
	
	