	function Places() {
		/* Object for the Places Screen */
		this.page = [];
		this.query = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Places.prototype.initialize = function() {
		browsr.screen = SCREEN_PLACES;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();
	}
	
	Places.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.query = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		Helper.destroy(this);
	}
	
	Places.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Places.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
					Helper.keyUpListNav(this);
				else
					Helper.keyUpScroll(this);
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
					Helper.keyDownListNav(this);
				else
					Helper.keyDownScroll(this);
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	Places.prototype.keyEnter = function() {
		if(this.total)
		{	
			var tplace = this.getSelectedPlace();
			var lindex = this.lindex;
			
			this.destroy();
			
			var params = [];
			
			params["place"] = tplace;
			
			browsr.addEvent(tplace._content + '\'s Photos', photostream.showByPlace, params, lindex, null, 'photoframe');
			photostream.showByPlace(params);
			params = null;
		}
	}
	
	Places.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	Places.prototype.keyRightList = function() {
		Helper.keyRightList(this);
	}
	
	Places.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Places.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Places.prototype.refresh = function() {
		this.displayPlaces();
	}
	
	Places.prototype.showInBrowser = function() {
		if(this.total)
		{
			var tplace = getSelectedPlace();
			var url = 'http://www.flickr.com/places/' + tplace.place_url;
			openURL(url);
		}
		else
		{
			alert('Unable to open in browser!');
		}
	}
	
	Places.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
			wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			toolbar.show(MENU_SHOW_IN_BROWSER.id);
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Places.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.displayPlaces();
	}
	
	Places.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.displayPlaces();
	}
	
	Places.prototype.showBySearch = function(params) {
	
		if(params == null)
		{
			params["query"] = null;
		}
		else if((params["query"] == undefined) || (params["query"] == null))
		{
			params["query"] = null;
		}
			
		places.query = params["query"];
		places.initialize();
		
		if(places.query != null)
		{
			Helper.setTitle('Search for: ' + places.query);
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				places.lindex = params["sindex"];
				places.cur_page = parseInt(places.lindex / MAX_LIST_SIZE) + 1;
			}
			
			flickr.places_find(places.query, places.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Places.prototype.handleFlickrResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				places.total = 0;
				var cur_page = places.cur_page;
				
				if(rsp.places)
				{
					var tplaces = rsp.places;
					places.total = rsp.places.place.length;
					rsp = null;
					places.cur_page = 1;
					
					while(tplaces.place.length)
					{
						if(tplaces.place.length > MAX_LIST_SIZE)
						{
							places.page[places.cur_page] = tplaces.place.slice(0, MAX_LIST_SIZE);
							tplaces.place.splice(0, MAX_LIST_SIZE);
							places.cur_page++;
						}
						else
						{
							places.page[places.cur_page] = tplaces.place.slice(0, tplaces.place.length);
							tplaces.place.splice(0, tplaces.place.length);
							places.cur_page++;
						}
					}
					
					tplaces = null;
				}
				
				if(places.total)
				{
					places.pages = places.cur_page-1;
					places.cur_page = cur_page;
				}
				
				if(places.total)
				{
					places.displayPlaces();
				}
				else
				{
					places.displayNoPlace();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	Places.prototype.displayPlaces = function () {
		if(Helper.isListMode())
			this.displayPlacesList();
		else
			this.displayPlacesTabs();
	}
	
	Places.prototype.displayPlacesList = function () {
		if(this.selector)
			this.selector.removeAll();
		
		var tplaces = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < tplaces.length; i++)
		{
			this.selector.addElement(tplaces[i]._content, placeImage, 'icon');
			Helper.hideIconGloss(i);
		}
		
		Helper.postDisplayList(this);
	}
	
	Places.prototype.displayPlacesTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tplace = this.page[this.cur_page][sindex];
		
		Helper.displayTabPage(this, this.lindex, tplace._content, 'Search for ' + this.query, placeImage, 'icon');
		this.auto_disp_tid = setTimeout( function() { places.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
			
		Helper.postDisplayTabs(this);
	}
	
	Places.prototype.displayNoPlace = function () {
		this.selector = null;
		var div = Helper.displayNoType('No places found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Places.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Places.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Places.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{	
			var tplace = this.getSelectedPlace();
			
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
				
			var params = [];
			
			params["method"] = "flickr.photos.search";
			params["place_id"] = tplace.place_id;
			params["auth_token"] = user.token;
			params["per_page"] = Constants.AUTO_FETCH_PHOTOCOUNT;
			
			flickr.photos_search(params, this.hrPhotos, PRI_HIGH);
		}
	}
	
	Places.prototype.hrPhotos = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(places)
				{
					var sindex = Helper.getSindex(places);
						
					if(parseInt(rsp.photos.total))
					{
						var tphotostream = rsp.photos.photo;
						rsp = null;
						
						Helper.destroyDescendants($('autof_elt_' + sindex));
						var photo_url = [];
						for(var i=0; i < tphotostream.length; i++)
						{
							var tphoto = tphotostream[i];
							photo_url[i] = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
						}
						
						Helper.setAFPhotoList(sindex, photo_url, 'large');
						places.resize();
						places.scroll.updateScrollbar();
					}
					else
					{
						Helper.setAFNoResult(sindex, 'No photos available!');
						places.resize();
						places.scroll.updateScrollbar();
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}
	
	Places.prototype.getSelectedPlace = function () {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
			return this.page[this.cur_page][sindex];
		else
			return null;
	}
	
	