	function RecentActivity() {
		/* Object for the RecentActivity Screen */
		this.page = [];
		this.user = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.by_photos = false;
		this.by_comments = false;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	RecentActivity.prototype.initialize = function() {
		browsr.screen = SCREEN_RECENT_ACTIVITY;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();
	}
	
	RecentActivity.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.user = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.by_photos = false;
		this.by_comments = false;
		
		Helper.destroy(this);
	}
	
	RecentActivity.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	RecentActivity.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
					Helper.keyUpListNav(this);
				else
					Helper.keyUpScroll(this);
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
					Helper.keyDownListNav(this);
				else
					Helper.keyDownScroll(this);
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	RecentActivity.prototype.keyEnter = function() {
		if(this.total)
		{
			var titem = this.getSelectedRecentActivity();
			var lindex = this.lindex;
			
			var params = [];
			params["item"] = titem;
			
			var photo_url = null;
			
			if(titem.type == 'photo')
			{
				photo_url = flickr.build_photo_url(titem.farm, titem.server, titem.id, titem.secret, PHOTO_S);
			}
			else if(titem.type == 'photoset')
			{
				photo_url = flickr.build_photo_url(titem.farm, titem.server, titem.primary, titem.secret, PHOTO_S);
			}
				
			this.destroy();
			
			var ttitle = '';
			if(titem.title._content)
				ttitle = titem.title._content;
			else
				ttitle = '(untitled)';
			
			browsr.addEvent('Recent Activities on: ' + ttitle, activities.show, params, lindex, photo_url, 'photoframe');
			activities.show(params);
			params = null;
		}
	}
	
	RecentActivity.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	RecentActivity.prototype.keyRightList = function() {
		Helper.keyRightList(this);
	}
	
	RecentActivity.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	RecentActivity.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	RecentActivity.prototype.refresh = function() {
		if(this.page[this.cur_page])
		{
			flickr.purge_all();
			this.displayRecentActivity();
		}
		else
		{
			flickr.purge_all();
			var params = [];
			params["user"] = this.user;
			params["page"] = this.cur_page;
			
			if(this.by_photos)
				this.showByPhotos(params);
			else if(this.by_comments)
				this.showByComments(params);
		}
	}
	
	RecentActivity.prototype.showInBrowser = function() {
		if(this.by_photos || this.by_comments)
		{
			var url = 'http://www.flickr.com/activity/';
			openURL(url);
		}
		else
		{
			alert('Unable to open in browser!');
		}
	}
	
	RecentActivity.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
			wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
			
			if(this.by_photos || this.by_comments)
				wid(MENU_SHOW_IN_BROWSER.id).setDimmed(false);
			else
				wid(MENU_SHOW_IN_BROWSER.id).setDimmed(true);
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			
			if(this.by_photos || this.by_comments)
				toolbar.show(MENU_SHOW_IN_BROWSER.id);
			else
				toolbar.hide(MENU_SHOW_IN_BROWSER.id);
				
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
		
	RecentActivity.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.refresh();
	}
	
	RecentActivity.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.refresh();
	}
	
	RecentActivity.prototype.showByPhotos = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		recent_activity.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			recent_activity.initialize();
		
		if(recent_activity.user != null)
		{
			recent_activity.by_photos = true;
			Helper.setTitle('Recent activities on your photos');
				
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				recent_activity.lindex = params["sindex"];
				recent_activity.cur_page = parseInt(recent_activity.lindex / MAX_LIST_SIZE) + 1;
				page = recent_activity.cur_page;
			}
				
			/* send request to flickr */
			flickr.activity_userPhotos(user.token, null, page, MAX_LIST_SIZE, recent_activity.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	RecentActivity.prototype.showByComments = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
			params["page"] = null;
		}
		
		if((params["user"] == undefined) || (params["user"] == null))
			params["user"] = user;
			
		recent_activity.user = params["user"];
		
		if((params["page"] == undefined) || (params["page"] == null))
			recent_activity.initialize();
		
		if(recent_activity.user != null)
		{
			recent_activity.by_comments = true;
			Helper.setTitle('Recent activities on your comments');
				
			var page = params["page"];
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				recent_activity.lindex = params["sindex"];
				recent_activity.cur_page = parseInt(recent_activity.lindex / MAX_LIST_SIZE) + 1;
				page = recent_activity.cur_page;
			}
				
			/* send request to flickr */
			flickr.activity_userComments(user.token, page, MAX_LIST_SIZE, recent_activity.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	RecentActivity.prototype.handleFlickrResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(rsp.items)
				{
					var cur_page = parseInt(rsp.items.page);
					recent_activity.page[cur_page] = rsp.items.item;
					recent_activity.total = parseInt(rsp.items.total);
					recent_activity.pages = parseInt(rsp.items.pages);
					rsp = null;
					
					if((recent_activity.cur_page == cur_page) && recent_activity.total)
					{
						recent_activity.displayRecentActivity();
					}
					else if(recent_activity.total == 0)
					{
						recent_activity.displayNoRecentActivity();
					}
				}
				else
				{
					recent_activity.displayNoRecentActivity();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	RecentActivity.prototype.displayRecentActivity = function () {
		if(Helper.isListMode())
			this.displayRecentActivityList();
		else
			this.displayRecentActivityTabs();
	}
	
	RecentActivity.prototype.displayRecentActivityList = function () {
		if(this.selector)
			this.selector.removeAll();
			
		var trecent_activity = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < trecent_activity.length; i++)
		{
			var text = '';
			var photo_url = '';
			var titem = trecent_activity[i];
			
			if(titem.type == 'photo')
			{
				photo_url = flickr.build_photo_url(titem.farm, titem.server, titem.id, titem.secret, PHOTO_S);
			}
			else if(titem.type == 'photoset')
			{
				photo_url = flickr.build_photo_url(titem.farm, titem.server, titem.primary, titem.secret, PHOTO_S);
			}
			
			if(titem.title && titem.title._content)
				text = text + titem.title._content;
			else
				text = text + '(untitled)';
			
			this.selector.addElement(text, photo_url, 'photoframe');
		}
		
		Helper.postDisplayList(this);
	}
	
	RecentActivity.prototype.displayRecentActivityTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var titem = this.page[this.cur_page][sindex];
		
		var subtitle = '';
		var photo_url = null;
		var title = '';
		
		if(titem.type == 'photo')
		{
			subtitle = 'Activity on photo';
			photo_url = flickr.build_photo_url(titem.farm, titem.server, titem.id, titem.secret, PHOTO_M);
		}
		else if(titem.type == 'photoset')
		{
			subtitle = 'Activity on set';
			photo_url = flickr.build_photo_url(titem.farm, titem.server, titem.primary, titem.secret, PHOTO_M);
		}
		
		if(this.by_photos)
			subtitle += ' you uploaded';
		else
			subtitle += ' you commented';
		
		if(titem.title && titem.title._content)
			title = titem.title._content;
		else
			title = '(untitled)';
		
		Helper.displayTabPage(this, this.lindex, title, subtitle, photo_url, 'photoframe');
		this.auto_disp_tid = setTimeout( function() { recent_activity.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
			
		Helper.postDisplayTabs(this);
	}
	
	RecentActivity.prototype.displayNoRecentActivity = function () {
		this.selector = null;
		var div = Helper.displayNoType('No Recent Activity found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	RecentActivity.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	RecentActivity.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	RecentActivity.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{
			var titem = this.getSelectedRecentActivity();
			
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
			
			var sindex = Helper.getSindex(this);
			
			var tevent = null;
			if(titem.activity && titem.activity.event)
				tevent = titem.activity.event;
				
			var ncomment = 0;
			var ntag = 0;
			var nfav = 0;
			var nnote = 0;
			var thead = 'Recently';
			var tlist = [];
			
			for(var i=0; i<tevent.length; i++)
			{
				if(tevent[i].type == 'comment')
					ncomment++;
				else if(tevent[i].type == 'tag')
					ntag++;
				else if(tevent[i].type == 'fave')
					nfav++;
				else if(tevent[i].type == 'note')
					nnote++;
			}
			
			if(ncomment)
				tlist[tlist.length] = ncomment + ' comments';
				
			if(ntag)
				tlist[tlist.length] = ntag + ' tags';
				
			if(nfav)
				tlist[tlist.length] = nfav + ' favs';
				
			if(nnote)
				tlist[tlist.length] = nnote + ' notes';
				
			if(titem.more)
				tlist[tlist.length] = ' And more!';
				
			Helper.setAFTextListHeader(sindex, thead, tlist);
			
			this.resize();
			this.scroll.updateScrollbar();
		}
	}
	
	RecentActivity.prototype.getSelectedRecentActivity = function() {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
			return this.page[this.cur_page][sindex];
	}
	
	
	
	