	function Sets() {
		/* Object for the Sets Screen */
		this.page = [];
		this.user = null;
		this.photo = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		this.div = null;
		this.scroll = null;
		this.selector = null;
		this.tabs = null;
		this.auto_disp_tid = 0;
	}
		
	Sets.prototype.initialize = function() {
		browsr.screen = SCREEN_SETS;

		Helper.initialize(this);
		Helper.showNavbar();
		Helper.hideTabbar();
	}
	
	Sets.prototype.destroy = function() {
		flickr.purge_all();
		
		this.page = [];
		this.user = null;
		this.photo = null;
		this.total = 0;
		this.pages = 0;
		this.cur_page = 1;
		this.lindex = 0;
		
		Helper.destroy(this);
	}
	
	Sets.prototype.resize = function() {
		this.scroll.resize();
		
		if(Helper.isListMode() && this.selector)
			this.selector.resize();
	}
	
	Sets.prototype.handleKeypress = function(key) {
		switch(key)
		{
			case KEY_UP:
				/* UP */
				if(Helper.isListMode())
				{
					Helper.keyUpListNav(this);
					this.updateBookmarkMenus();
				}
				else
				{
					Helper.keyUpScroll(this);
				}
				break;
				
			case KEY_DOWN:
				/* DOWN */
				if(Helper.isListMode())
				{
					Helper.keyDownListNav(this);
					this.updateBookmarkMenus();
				}
				else
				{
					Helper.keyDownScroll(this);
				}
				break;
				
			case KEY_ENTER:
				/* ENTER */
				this.keyEnter();
				break;
				
			case KEY_LEFT:
				/* LEFT */
				if(Helper.isListMode())
					this.keyLeftList();
				else
					this.keyLeftTab();
				break;
				
			case KEY_RIGHT:
				/* RIGHT */
				if(Helper.isListMode())
					this.keyRightList();
				else
					this.keyRightTab();
				break;
		}
	}
	
	Sets.prototype.keyEnter = function() {
		if(this.total)
		{	
			var tset = this.getSelectedSet();
			var lindex = this.lindex;
			var photo_url = null;
			
			if(tset.farm)
				photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_S);
			
			this.destroy();
			
			var params = [];
			
			params["set"] = tset;
			
			var ttitle = 'Set: ';
			if(tset.title._content)
				ttitle += tset.title._content;
			else
				ttitle += tset.title;
			
			if(photo_url)
				browsr.addEvent(ttitle, set.show, params, lindex, photo_url, 'photoframe');
			else
				browsr.addEvent(ttitle, set.show, params, lindex, setsImage, 'icon');
				
			set.show(params);
			params = null;
		}
	}
	
	Sets.prototype.keyLeftList = function() {
		Helper.keyLeftList(this);
	}
	
	Sets.prototype.keyRightList = function() {	
		Helper.keyRightList(this);
	}
	
	Sets.prototype.keyLeftTab = function() {
		Helper.keyLeftTabPage(this);
	}
	
	Sets.prototype.keyRightTab = function() {
		Helper.keyRightTabPage(this);
	}
	
	Sets.prototype.refresh = function() {
		this.displaySets();
	}
	
	Sets.prototype.showInBrowser = function() {
		//needs owner info
	}
	
	Sets.prototype.updateMenus = function() {
		if(isNokia)
		{
			wid(MENU_WHERE_AM_I.id).setDimmed(false);
			wid(MENU_GOT_LOST.id).setDimmed(false);
			wid(MENU_CLEAR_HISTORY.id).setDimmed(false);
			wid(MENU_REFRESH.id).setDimmed(false);
			wid(MENU_SHOW_IN_BROWSER.id).setDimmed(true);
			wid(MENU_SETTINGS.id).setDimmed(false);
			
			if(Helper.isListMode())
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(false);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(true);
			}
			else
			{
				wid(MENU_SWITCH_TO_TABS.id).setDimmed(true);
				wid(MENU_SWITCH_TO_LIST.id).setDimmed(false);
			}
			
			this.updateBookmarkMenus();
		}
		else
		{
			toolbar.show(MENU_WHERE_AM_I.id);
			toolbar.show(MENU_GOT_LOST.id);
			toolbar.show(MENU_CLEAR_HISTORY.id);
			toolbar.show(MENU_REFRESH.id);
			toolbar.hide(MENU_SHOW_IN_BROWSER.id);
			toolbar.hide(MENU_FRAME.id);
			toolbar.show(MENU_BACKGROUND.id);
			toolbar.show(MENU_SETTINGS.id);
			
			if(Helper.isListMode())
			{
				toolbar.show(MENU_SWITCH_TO_TABS.id);
				toolbar.hide(MENU_SWITCH_TO_LIST.id);
			}
			else
			{
				toolbar.hide(MENU_SWITCH_TO_TABS.id);
				toolbar.show(MENU_SWITCH_TO_LIST.id);
			}
		}
	}
	
	Sets.prototype.updateBookmarkMenus = function() {
		var tset = this.getSelectedSet();
		
		if(tset)
		{
			if(bmarks.findSetInBmarks(tset.id))
			{
				wid(MENU_ADD_TO_BMARKS.id).setDimmed(true);
				wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(false);
			}
			else
			{	
				wid(MENU_ADD_TO_BMARKS.id).setDimmed(false);
				wid(MENU_REMOVE_FROM_BMARKS.id).setDimmed(true);
			}
		}
	}
		
	Sets.prototype.switchToTabs = function() {
		Helper.switchToTabsPage(this);
		this.displaySets();
	}
	
	Sets.prototype.switchToList = function() {
		Helper.switchToListPage(this);
		this.displaySets();
	}
	
	Sets.prototype.showByUser = function(params) {
	
		if(params == null)
		{
			params["user"] = user;
		}
		else if((params["user"] == undefined) || (params["user"] == null))
		{
			params["user"] = user;
		}
			
		sets.user = params["user"];
		sets.initialize();
		
		if(sets.user != null)
		{
			Helper.setTitle(sets.user.username + '\'s sets');
			
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				sets.lindex = params["sindex"];
				sets.cur_page = parseInt(sets.lindex / MAX_LIST_SIZE) + 1;
			}
			
			flickr.photosets_getList(user.token, sets.user.user_nsid, sets.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Sets.prototype.showByPhoto = function(params) {
	
		if(params == null)
		{
			params["photo"] = null;
			params["user_id"] = null; /* unused */
		}
		else if((params["photo"] == undefined) || (params["photo"] == null))
		{
			params["photo"] = null;
		}
		
		sets.photo = params["photo"];
		sets.initialize();
		
		if(sets.photo != null)
		{
			if(sets.photo.title != '')
				Helper.setTitle(sets.photo.title + '\'s sets');
			else
				Helper.setTitle('(untitled)' + '\'s sets');
				
			if((params["sindex"] != undefined) || (params["sindex"] != null))
			{
				sets.lindex = params["sindex"];
				sets.cur_page = parseInt(sets.lindex / MAX_LIST_SIZE) + 1;
			}
				
			flickr.photos_getAllContexts(user.token, sets.photo.id, sets.handleFlickrResponse, PRI_HIGH);
		}
	}
	
	Sets.prototype.handleFlickrResponse = function(rsp) {
		/* this refers to the window here */
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				sets.total = 0;
				var cur_page = sets.cur_page;
				
				if(rsp.photosets)
				{
					var tsets = rsp.photosets;
					sets.total = rsp.photosets.photoset.length;
					rsp = null;
					sets.cur_page = 1;
					
					while(tsets.photoset.length)
					{
						if(tsets.photoset.length > MAX_LIST_SIZE)
						{
							sets.page[sets.cur_page] = tsets.photoset.slice(0, MAX_LIST_SIZE);
							tsets.photoset.splice(0, MAX_LIST_SIZE);
							sets.cur_page++;
						}
						else
						{
							sets.page[sets.cur_page] = tsets.photoset.slice(0, tsets.photoset.length);
							tsets.photoset.splice(0, tsets.photoset.length);
							sets.cur_page++;
						}
					}
					
					tsets = null;
				}
				else if(rsp.set)
				{
					var tsets = rsp.set;
					sets.total = rsp.set.length;
					rsp = null;
					sets.cur_page = 1;
					
					while(tsets.length)
					{
						if(tsets.length > MAX_LIST_SIZE)
						{
							sets.page[sets.cur_page] = tsets.slice(0, MAX_LIST_SIZE);
							tsets.splice(0, MAX_LIST_SIZE);
							sets.cur_page++;
						}
						else
						{
							sets.page[sets.cur_page] = tsets.slice(0, tsets.length);
							tsets.splice(0, tsets.length);
							sets.cur_page++;
						}
					}
				}
				
				if(sets.total)
				{
					sets.pages = sets.cur_page-1;
					sets.cur_page = cur_page;
				}
				
				if(sets.total)
				{
					sets.displaySets();
				}
				else
				{
					sets.displayNoSet();
				}
			}
			else
			{
				/* error */
				alert('failure : ' + rsp.message);
			}
		}
	}
	
	Sets.prototype.displaySets = function () {
		if(Helper.isListMode())
			this.displaySetsList();
		else
			this.displaySetsTabs();
	}
	
	Sets.prototype.displaySetsList = function () {
		if(this.selector)
			this.selector.removeAll();
		
		var tsets = this.page[this.cur_page];
		
		/* add to selector */
		for(var i=0; i < tsets.length; i++)
		{
			var tset = tsets[i];
			var photo_url = null;
			var text = '';
			
			if(tset.farm)
			{
				photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_S);
			}
			else
			{
				/* send a flickr request */
				flickr.photosets_getInfo(user.token, tset.id, this.handleSetsIconsResponse, PRI_HIGH);
			}
				
			if(tset.title._content)
				text = tset.title._content;
			else
				text = tset.title;
			
			if(photo_url)
				this.selector.addElement(text, photo_url, 'photoframe');
			else
				this.selector.addElement(text, setsImage, 'icon');
		}
		
		Helper.postDisplayList(this);
	}
	
	Sets.prototype.displaySetsTabs = function () {
		if(this.tabs)
			this.tabs.removeAll();
			
		var sindex = this.lindex % MAX_LIST_SIZE;
		
		var tset = this.page[this.cur_page][sindex];
		
		var photo_url = null;
		if(tset.farm)
			photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_M);
			
		var title = '';
		if(tset.title._content)
			title = tset.title._content;
		else
			title = tset.title;
			
		var subtitle = '';
		if(this.photo)
		{
			if(this.photo.title != '')
				subtitle = this.photo.title + '\'s sets';
			else
				subtitle = '(untitled)' + '\'s sets';
		}
		else if(this.user)
		{
			subtitle = this.user.username + '\'s sets';
		}
		
		if(photo_url)
			Helper.displayTabPage(this, this.lindex, title, subtitle, photo_url, 'photoframe');
		else
			Helper.displayTabPage(this, this.lindex, title, subtitle, setsImage, 'icon');
		this.auto_disp_tid = setTimeout( function() { sets.autoFetch() }, Constants.AUTO_FETCH_TIMEOUT);
		
		Helper.postDisplayTabs(this);
	}
	
	Sets.prototype.displayNoSet = function () {
		this.selector = null;
		this.tab_container = null;
		var div = Helper.displayNoType('No sets found!');
		this.scroll.add(div);
		this.updateMenus();
	}
	
	Sets.prototype.selectedListItem = function() {
		return Helper.selectedListItem(this);
	}
	
	Sets.prototype.updateNavigator = function() {
		Helper.updateNavigator(this);
	}
	
	Sets.prototype.handleSetsIconsResponse = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				if(sets && sets.selector)
				{
					if(rsp.photoset)
					{
						var tset = rsp.photoset;
						var photo_url = flickr.build_photo_url(tset.farm, tset.server, tset.primary, tset.secret, PHOTO_S);
						rsp = null;
						
						var set_index = -1;
						var current_page = sets.page[sets.cur_page];
						
						for(var i=0; i < current_page.length; i++)
						{
							if(current_page[i].id == tset.id)
							{
								set_index = i;
								sets.selector.replaceElement(set_index, tset.title._content, photo_url);
							}
						}
					}
				}
			}
			else
			{
				/* error */
				alert('failure: ' + rsp.msg);
			}
		}
	}
	
	Sets.prototype.autoFetch = function() {
		if(this.cur_page && this.page[this.cur_page])
		{	
			var tset = this.getSelectedSet();
			
			if(!(Helper.isListMode()))
				this.tabs.autoFetch();
				
			flickr.photosets_getPhotos(user.token, tset.id, null, null, null, null, Constants.AUTO_FETCH_PHOTOCOUNT, this.hrPhotos, PRI_HIGH);
		}
	}
	
	Sets.prototype.hrPhotos = function(rsp) {
		if(rsp != null)
		{
			if(rsp.stat == 'ok')
			{
				var tphotostream = rsp.photoset.photo;
				var rsp_id = rsp.photoset.id;
				rsp = null;
				
				if(sets)
				{
					
					var sindex = Helper.getSindex(sets);
						
					/* check if the owner of the rsp and the owner of the selected item match */			
					var sel_id = sets.page[sets.cur_page][sindex].id;
					
					if(rsp_id == sel_id)
					{
						if(tphotostream.length)
						{
							Helper.destroyDescendants($('autof_elt_' + sindex));
							var photo_url = [];
							for(var i=0; i < tphotostream.length; i++)
							{
								var tphoto = tphotostream[i];
								photo_url[i] = flickr.build_photo_url(tphoto.farm, tphoto.server, tphoto.id, tphoto.secret, PHOTO_S);
							}
							
							Helper.setAFPhotoList(sindex, photo_url, 'large');
							sets.resize();
							sets.scroll.updateScrollbar();
						}
						else
						{
							Helper.setAFNoResult(sindex, 'No photos available!');
							sets.resize();
							sets.scroll.updateScrollbar();
						}
					}
				}
			}
			else
			{
				/* error */
			}
		}
	}
	
	Sets.prototype.addToBookmarks = function() {
		if(this.cur_page && this.page[this.cur_page])
		{	
			var tset = this.getSelectedSet();
			
			if(bmarks && tset)
			{
				var ttitle = '';
					
				if(tset.title._content)
					ttitle = tset.title._content;
				else
					ttitle = tset.title;
				
				bmarks.addSetToBmarks( {id:tset.id, title:ttitle} );
			}
		}
	}
	
	Sets.prototype.removeFromBookmarks = function() {
		if(this.cur_page && this.page[this.cur_page])
		{
			var tset = this.getSelectedSet();
			
			if(bmarks && tset)
			{
				bmarks.removeSetFromBmarks(tset.id);
			}
		}
	}
	
	Sets.prototype.getSelectedSet = function() {
		if(Helper.isListMode())
		{
			sindex = this.selector.selected_index;
			this.lindex = this.selectedListItem();
		}
		else
		{
			this.cur_page = parseInt(this.lindex / MAX_LIST_SIZE) + 1;
			sindex = this.lindex % MAX_LIST_SIZE;
		}
		
		if(this.total)
			return this.page[this.cur_page][sindex];
		else
			return null;
	}
	
	